
From: Anton Blanchard <anton@samba.org>

Replace open coded versions with for_each_cpu()/for_each_online_cpu().

Signed-off-by: Anton Blanchard <anton@samba.org>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 /dev/null                                 |    0 
 25-akpm/drivers/oprofile/cpu_buffer.c     |   20 ++++----------------
 25-akpm/drivers/oprofile/oprofile_stats.c |   10 ++--------
 3 files changed, 6 insertions(+), 24 deletions(-)

diff -L cpu_buffer.c -puN /dev/null /dev/null
diff -puN drivers/oprofile/cpu_buffer.c~use-for_each_cpu-in-oprofile-code drivers/oprofile/cpu_buffer.c
--- 25/drivers/oprofile/cpu_buffer.c~use-for_each_cpu-in-oprofile-code	2004-09-05 14:44:57.645296272 -0700
+++ 25-akpm/drivers/oprofile/cpu_buffer.c	2004-09-05 14:44:57.655294752 -0700
@@ -36,11 +36,8 @@ static void __free_cpu_buffers(int num)
 {
 	int i;
  
-	for (i = 0; i < NR_CPUS; ++i) {
-		if (!cpu_online(i))
-			continue;
+	for_each_online_cpu(i)
 		vfree(cpu_buffer[i].buffer);
-	}
 }
  
  
@@ -50,12 +47,9 @@ int alloc_cpu_buffers(void)
  
 	unsigned long buffer_size = fs_cpu_buffer_size;
  
-	for (i = 0; i < NR_CPUS; ++i) {
+	for_each_online_cpu(i) {
 		struct oprofile_cpu_buffer * b = &cpu_buffer[i];
  
-		if (!cpu_online(i))
-			continue;
-
 		b->buffer = vmalloc(sizeof(struct op_sample) * buffer_size);
 		if (!b->buffer)
 			goto fail;
@@ -94,12 +88,9 @@ void start_cpu_timers(void)
 
 	timers_enabled = 1;
 
-	for (i = 0; i < NR_CPUS; ++i) {
+	for_each_online_cpu(i) {
 		struct oprofile_cpu_buffer * b = &cpu_buffer[i];
 
-		if (!cpu_online(i))
-			continue;
-
 		add_timer_on(&b->timer, i);
 	}
 }
@@ -111,12 +102,9 @@ void end_cpu_timers(void)
 
 	timers_enabled = 0;
 
-	for (i = 0; i < NR_CPUS; ++i) {
+	for_each_online_cpu(i) {
 		struct oprofile_cpu_buffer * b = &cpu_buffer[i];
 
-		if (!cpu_online(i))
-			continue;
-
 		del_timer_sync(&b->timer);
 	}
 
diff -puN drivers/oprofile/oprofile_stats.c~use-for_each_cpu-in-oprofile-code drivers/oprofile/oprofile_stats.c
--- 25/drivers/oprofile/oprofile_stats.c~use-for_each_cpu-in-oprofile-code	2004-09-05 14:44:57.646296120 -0700
+++ 25-akpm/drivers/oprofile/oprofile_stats.c	2004-09-05 14:44:57.655294752 -0700
@@ -22,10 +22,7 @@ void oprofile_reset_stats(void)
 	struct oprofile_cpu_buffer * cpu_buf; 
 	int i;
  
-	for (i = 0; i < NR_CPUS; ++i) {
-		if (!cpu_possible(i))
-			continue;
-
+	for_each_cpu(i) {
 		cpu_buf = &cpu_buffer[i]; 
 		cpu_buf->sample_received = 0;
 		cpu_buf->sample_lost_overflow = 0;
@@ -49,10 +46,7 @@ void oprofile_create_stats_files(struct 
 	if (!dir)
 		return;
 
-	for (i = 0; i < NR_CPUS; ++i) {
-		if (!cpu_possible(i))
-			continue;
-
+	for_each_cpu(i) {
 		cpu_buf = &cpu_buffer[i]; 
 		snprintf(buf, 10, "cpu%d", i);
 		cpudir = oprofilefs_mkdir(sb, dir, buf);
diff -L oprofile_stats.c -puN /dev/null /dev/null
_
